# Purpose:
Python mail things are little bit complicated. There are many blogs and questions about it. I just made it very simple.
You can use it in your classes as inherit it or creating instances.

###### Dependence:
smtplib and email which are built-in libraries.


## Features:
gmail and other services are supported. You can use gmail instance if you want or you can set your company's smtp
settings in other services classes. 
Aware that there will be an error if you create your other_services instance without filling your smtp settings.
You need to assign a variable then fill class property smpt and create your instance. For details, see test.py

You may type your username or detailed mail address like ucok.umut or ucok.umut@gmail.com


I didn't implement file attachment yet. You may want to do that. Pretty simple.
You can open issues or RFC.

# Authors and Contributors

    Core contributors:

    Umut Ucok: primary author.  : ucok.umut@gmail.com

